package com.repair.services;

import com.baomidou.mybatisplus.extension.service.IService;
import com.repair.model.pojo.RepairAdmin;
import com.repair.model.request.updateRepairAdminRequest;
import com.repair.model.result.PageUtils;

import java.util.List;

/**
 * <p>
 * 服务类
 * </p>
 *
 * @author ceshi
 * @since 2023-07-05
 */
public interface RepairAdminService extends IService<RepairAdmin> {
    int insertRepairAdmin(RepairAdmin ra);

    int deleteRepairAdminById(String id);

    RepairAdmin getRepairByAccount(String Account);

    RepairAdmin getRepairByCardnumber(String Cardnumber);

    PageUtils<RepairAdmin> queryPageList(int currentPage, int pageCount, String account, String startTime, String endTime);

    RepairAdmin getRepairById(String id);

    int updateRepaiRadmin(updateRepairAdminRequest urar);

    int updateRepairAdmin(RepairAdmin ra);

    List<RepairAdmin> queryRepairAdminList(String account, String startTime,String endTime);
}
